# Changelog

All notable changes to this project will be documented in this file.


### 🔧 Chores



- update changelog for v0.1.11 [4425031…](https://github.com/sralter/pymaap/commit/4425031bf508e56e2171a8c4886a79cde9b98603)

- disable runner action for now [139b71b…](https://github.com/sralter/pymaap/commit/139b71b77d925bf93796451a180a708eb64d64cb)




### 🔧 Chores



- update changelog for v0.1.9 [e640c85…](https://github.com/sralter/pymaap/commit/e640c85aaeaf4112dc88cdc04b1a8bfeb430e477)

- fix .post1 addition to version names [aaf0213…](https://github.com/sralter/pymaap/commit/aaf0213d2c010967e4643bafe1f5a7fbf79796d5)




### 🔧 Chores



- update changelog for v0.1.71 [0631039…](https://github.com/sralter/pymaap/commit/0631039cd0d02e85eda00b233582da3ffa749215)

- change python version tests to just 3.11 and 3.12 [f9b4cdb…](https://github.com/sralter/pymaap/commit/f9b4cdb78542e02449c9ee51d25de9b5f562c123)

- update changelog for 0.1.8 [21be6ac…](https://github.com/sralter/pymaap/commit/21be6ac5180d1118dcc84016f4252f8d480136ee)

- update changelog for v0.1.9.dev1+g21be6ac [d0c9cd9…](https://github.com/sralter/pymaap/commit/d0c9cd92088d823dafa7c386619ad6e39617514c)

- update pyproject toml with setuptools_scm version name handling [1121d17…](https://github.com/sralter/pymaap/commit/1121d17c64dd1ee987613010e104605ac50cc32b)




### 🔧 Chores



- fix changelog template for correct GitHub commit links [a82f957…](https://github.com/sralter/pymaap/commit/a82f957cb021a1af5fcd2134f8e613236ea8bca6)

- try to fix extra spaces [67e71f2…](https://github.com/sralter/pymaap/commit/67e71f228a133f2bf7edb6afb21d9820031f7384)

- prettify version names from v0.1.6 to Version 0.1.6 [0915672…](https://github.com/sralter/pymaap/commit/0915672f0481f0bbb9a1537322bdfe41988e30ed)




### 📝 Docs



- add changelog sorting newest first [6241468…](https://github.com/sralter/pymaap/commit/6241468db64f4c4ba5d87fa988eb506401eb17aa)

- add badge [995d03a…](https://github.com/sralter/pymaap/commit/995d03a903c880e4520440c8b5b353e5a9ef3929)

- update test.yml with coverage reports uploading to gh-pages [f4d27c8…](https://github.com/sralter/pymaap/commit/f4d27c85ed2a091199154f32f12f5feb7e7dd976)

- fix table of contents anchor link names [1eb0609…](https://github.com/sralter/pymaap/commit/1eb06099912213108d036e0c8f741c04f07f9b6e)



### 🩹 Fixes



- fix test behavior and add pytest report to github ui [912f315…](https://github.com/sralter/pymaap/commit/912f31565feb8699a28eb9def7c35630c64f5903)


Generated by [git‑cliff](https://github.com/orhun/git-cliff)
